# BlueDynamics Alliance
# http://www.bluedynamics.com.com

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

__author__ = """Jens Klein <jens@bluedynamics.com>"""
__docformat__ = 'plaintext'

from zope.interface import implements
from zope.interface import Attribute
from zope.component.interfaces import IObjectEvent


class IObjectWillBeTranslatedEvent(IObjectEvent):
    """Sent before an object is translated."""

    object = Attribute("The object to be translated.")
    language = Attribute("Target language.")


class IObjectTranslatedEvent(IObjectEvent):
    """Sent after an object was translated."""

    object = Attribute("The object to be translated.")
    target = Attribute("The translation target object.")
    language = Attribute("Target language.")


class ObjectWillBeTranslatedEvent(object):
    """Sent before an object is translated."""
    implements(IObjectWillBeTranslatedEvent)

    def __init__(self, context, language):
        self.object = context
        self.language = language


class ObjectTranslatedEvent(object):
    """Sent after an object was translated."""
    implements(IObjectTranslatedEvent)

    def __init__(self, context, target, language):
        self.object = context
        self.target = target
        self.language = language
